@@ -14,7 +14,7 @@ use warnings;
 
 #$| = 1;
 
-use 5.006_001;
+use 5.008_001;
 require Exporter;
 
 use constant IS_PRE_516_PERL => $] < 5.016;
@@ -29,7 +29,7 @@ our ( $Indent, $Trailingcomma, $Purity, $Pad, $Varname, $Useqq, $Terse, $Freezer
 our ( @ISA, @EXPORT, @EXPORT_OK, $VERSION );
 
 BEGIN {
-    $VERSION = '2.179_50'; # Don't forget to set version and release
+    $VERSION = '2.180_50'; # Don't forget to set version and release
                         # date in POD below!
 
     @ISA = qw(Exporter);
@@ -123,46 +123,17 @@ sub new {
 
 # Packed numeric addresses take less memory. Plus pack is faster than sprintf
 
-# Most users of current versions of Data::Dumper will be 5.008 or later.
-# Anyone on 5.6.1 and 5.6.2 upgrading will be rare (particularly judging by
-# the bug reports from users on those platforms), so for the common case avoid
-# complexity, and avoid even compiling the unneeded code.
-
-sub init_refaddr_format {
-}
-
 sub format_refaddr {
     require Scalar::Util;
     pack "J", Scalar::Util::refaddr(shift);
 };
 
-if ($] < 5.008) {
-    eval <<'EOC' or die;
-    no warnings 'redefine';
-    my $refaddr_format;
-    sub init_refaddr_format {
-        require Config;
-        my $f = $Config::Config{uvxformat};
-        $f =~ tr/"//d;
-        $refaddr_format = "0x%" . $f;
-    }
-
-    sub format_refaddr {
-        require Scalar::Util;
-        sprintf $refaddr_format, Scalar::Util::refaddr(shift);
-    }
-
-    1
-EOC
-}
-
 #
 # add-to or query the table of already seen references
 #
 sub Seen {
   my($s, $g) = @_;
   if (defined($g) && (ref($g) eq 'HASH'))  {
-    init_refaddr_format();
     my($k, $v, $id);
     while (($k, $v) = each %$g) {
       if (defined $v) {
@@ -252,7 +223,6 @@ sub Dumpperl {
   my(@out, $val, $name);
   my($i) = 0;
   local(@post);
-  init_refaddr_format();
 
   $s = $s->new(@_) unless ref $s;
 
@@ -545,7 +515,7 @@ sub _dump {
       else {
         local $s->{useqq} = IS_PRE_516_PERL && ($s->{useqq} || $name =~ /[^\x00-\x7f]/) ? 1 : $s->{useqq};
         $sname = $s->_dump(
-          $name eq 'main::' || $] < 5.007 && $name eq "main::\0"
+          $name eq 'main::'
             ? ''
             : $name,
           "",
@@ -778,7 +748,7 @@ sub qquote {
        # the string is UTF-8 but there are no UTF-8 variant characters in it.
        # We want that to come out as \x{} anyway.  We need is_utf8() to do
        # this.
-       || (! $IS_ASCII && $] ge 5.008_001 && utf8::is_utf8($_));
+       || (! $IS_ASCII && utf8::is_utf8($_));
 
   return qq("$_") unless /[[:^print:]]/;  # fast exit if only printables
 
@@ -798,7 +768,7 @@ sub qquote {
       if ($IS_ASCII) {
         s/([\200-\240])/'\\'.sprintf('%o',ord($1))/eg;
       }
-      elsif ($] ge 5.007_003) {
+      else {
         my $high_control = utf8::unicode_to_native(0x9F);
         s/$high_control/sprintf('\\%o',ord($1))/eg;
       }
@@ -817,10 +787,6 @@ sub qquote {
   return qq("$_");
 }
 
-# helper sub to sort hash keys in Perl < 5.8.0 where we don't have
-# access to sortsv() from XS
-sub _sortkeys { [ sort keys %{$_[0]} ] }
-
 sub _refine_name {
     my $s = shift;
     my ($name, $val, $i) = @_;
@@ -1451,12 +1417,9 @@ for L<B::Deparse>.
 
 SCALAR objects have the weirdest looking C<bless> workaround.
 
-Pure Perl version of C<Data::Dumper> escapes UTF-8 strings correctly
-only in Perl 5.8.0 and later.
-
 =head2 NOTE
 
-Starting from Perl 5.8.1 different runs of Perl will have different
+Different runs of Perl will have different
 ordering of hash keys.  The change was done for greater security,
 see L<perlsec/"Algorithmic Complexity Attacks">.  This means that
 different runs of Perl will have different Data::Dumper outputs if
@@ -1476,7 +1439,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 2.179_50
+Version 2.180_50
 
 =head1 SEE ALSO
 
